"use client"

import type React from "react"

import { useEffect, useState, Suspense } from "react"
import { useRouter, useSearchParams } from "next/navigation"
import {
  GoogleAuthProvider,
  signInWithPopup,
  createUserWithEmailAndPassword,
  signInWithEmailAndPassword,
} from "firebase/auth"
import { useAuth } from "@/contexts/auth-context"
import { auth } from "@/lib/firebase/config"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { useToast } from "@/hooks/use-toast"
import { AlertCircle, ArrowRight, Check, Eye, EyeOff, Loader2, LockKeyhole, Mail } from 'lucide-react'
import { Separator } from "@/components/ui/separator"
import { useLanguage } from "@/contexts/language-context"
import { motion } from "framer-motion"
import Image from "next/image"
import Link from "next/link"
import { Alert, AlertDescription } from "@/components/ui/alert"

// Component that uses search params
function AuthContent() {
  const { user, loading } = useAuth()
  const router = useRouter()
  const { toast } = useToast()
  const { t } = useLanguage()
  const searchParams = useSearchParams()

  const [email, setEmail] = useState("")
  const [password, setPassword] = useState("")
  const [showPassword, setShowPassword] = useState(false)
  const [isSubmitting, setIsSubmitting] = useState(false)
  const [authError, setAuthError] = useState<string | null>(null)
  const [activeTab, setActiveTab] = useState(searchParams.get("tab") === "signin" ? "signin" : "signup")

  useEffect(() => {
    // Redirect to home if user is already logged in and not loading
    if (!loading && user) {
      router.push("/")
    }
  }, [user, loading, router])

  const handleGoogleSignIn = async () => {
    setIsSubmitting(true)
    setAuthError(null)
    const provider = new GoogleAuthProvider()
    try {
      await signInWithPopup(auth, provider)
      toast({
        title: t("signedIn"),
        description: t("googleSignInSuccess"),
      })
      // Redirect is handled by the useEffect hook
    } catch (error: any) {
      console.error("Error signing in with Google: ", error)
      setAuthError(error.message || t("googleSignInError"))
      toast({
        variant: "destructive",
        title: t("signInError"),
        description: error.message || t("googleSignInError"),
      })
    } finally {
      setIsSubmitting(false)
    }
  }

  const handleEmailPasswordSignIn = async (e: React.FormEvent) => {
    e.preventDefault()
    if (!email || !password) {
      setAuthError(t("enterEmailAndPassword"))
      return
    }
    setIsSubmitting(true)
    setAuthError(null)
    try {
      await signInWithEmailAndPassword(auth, email, password)
      toast({
        title: t("signedIn"),
        description: t("emailSignInSuccess"),
      })
      // Redirect is handled by the useEffect hook
    } catch (error: any) {
      console.error("Error signing in with email/password: ", error)
      setAuthError(error.message || t("emailSignInError"))
      toast({
        variant: "destructive",
        title: t("signInError"),
        description: error.message || t("emailSignInError"),
      })
    } finally {
      setIsSubmitting(false)
    }
  }

  const handleEmailPasswordSignUp = async (e: React.FormEvent) => {
    e.preventDefault()
    if (!email || !password) {
      setAuthError(t("enterEmailAndPassword"))
      return
    }
    setIsSubmitting(true)
    setAuthError(null)
    try {
      await createUserWithEmailAndPassword(auth, email, password)
      toast({
        title: t("signedUp"),
        description: t("accountCreatedSuccess"),
      })
      // Redirect is handled by the useEffect hook
    } catch (error: any) {
      console.error("Error signing up with email/password: ", error)
      setAuthError(error.message || t("accountCreationError"))
      toast({
        variant: "destructive",
        title: t("signUpError"),
        description: error.message || t("accountCreationError"),
      })
    } finally {
      setIsSubmitting(false)
    }
  }

  if (loading || user) {
    return (
      <div className="flex justify-center items-center min-h-[calc(100vh-4rem)]">
        <div className="flex flex-col items-center gap-4">
          <Loader2 className="h-12 w-12 animate-spin text-emerald-500" />
          <p className="text-muted-foreground animate-pulse">
            {loading ? t("loading") || "Loading..." : t("redirecting") || "Redirecting..."}
          </p>
        </div>
      </div>
    )
  }

  return (
    <div className="min-h-[calc(100vh-4rem)] p-4 md:p-8 bg-gradient-to-b from-slate-950 via-slate-900 to-slate-800">
      <div className="container mx-auto flex flex-col lg:flex-row items-center justify-center gap-12 py-8 md:py-16">
        {/* Left side - Branding and info */}
        <motion.div
          initial={{ opacity: 0, x: -20 }}
          animate={{ opacity: 1, x: 0 }}
          transition={{ duration: 0.5 }}
          className="w-full lg:w-1/2 max-w-md text-center lg:text-left"
        >
          <div className="mb-8 flex justify-center lg:justify-start">
            <Image src="/psonio.png" alt="Logo" width={180} height={107} priority />
          </div>

          <h1 className="text-4xl md:text-5xl font-bold mb-6 text-white">
            {t("welcomeTo") || "Welcome to"}{" "}
            <span className="text-transparent bg-clip-text bg-gradient-to-r from-emerald-400 to-teal-400">
              {t("appName") || "GroceryApp"}
            </span>
          </h1>

          <p className="text-lg text-slate-300 mb-8">
            {t("authPageDescription") ||
              "Simplify your shopping experience with smart lists, real-time sync, and price alerts."}
          </p>

          <div className="hidden lg:block space-y-6">
            {[
              {
                icon: <Check className="h-5 w-5 text-emerald-500" />,
                text: t("featureSync") || "Sync across all your devices",
              },
              {
                icon: <Check className="h-5 w-5 text-emerald-500" />,
                text: t("featureShare") || "Share lists with family and friends",
              },
              {
                icon: <Check className="h-5 w-5 text-emerald-500" />,
                text: t("featureTrack") || "Track prices and get alerts",
              },
            ].map((feature, i) => (
              <div key={i} className="flex items-center gap-3">
                <div className="flex-shrink-0 w-8 h-8 rounded-full bg-emerald-500/10 flex items-center justify-center">
                  {feature.icon}
                </div>
                <p className="text-slate-300">{feature.text}</p>
              </div>
            ))}
          </div>
        </motion.div>

        {/* Right side - Auth form */}
        <motion.div
          initial={{ opacity: 0, x: 20 }}
          animate={{ opacity: 1, x: 0 }}
          transition={{ duration: 0.5, delay: 0.1 }}
          className="w-full lg:w-1/2 max-w-md"
        >
          <Card className="border-slate-700 bg-slate-900/50 backdrop-blur-sm shadow-xl">
            <CardHeader className="space-y-1">
              <CardTitle className="text-2xl font-bold text-white">
                {activeTab === "signin" ? t("signIn") || "Sign In" : t("signUp") || "Sign Up"}
              </CardTitle>
              <CardDescription className="text-slate-400">
                {activeTab === "signin"
                  ? t("signInDescription") || "Sign in to your account to continue"
                  : t("signUpDescription") || "Create a new account to get started"}
              </CardDescription>
            </CardHeader>
            <CardContent className="space-y-4">
              <Tabs defaultValue={activeTab} onValueChange={setActiveTab} className="w-full">
                <TabsList className="grid w-full grid-cols-2 mb-6 bg-slate-800">
                  <TabsTrigger
                    value="signin"
                    className="data-[state=active]:bg-slate-700 data-[state=active]:text-white"
                  >
                    {t("signIn") || "Sign In"}
                  </TabsTrigger>
                  <TabsTrigger
                    value="signup"
                    className="data-[state=active]:bg-slate-700 data-[state=active]:text-white"
                  >
                    {t("signUp") || "Sign Up"}
                  </TabsTrigger>
                </TabsList>

                {/* Sign In Tab */}
                <TabsContent value="signin" className="space-y-4">
                  <form onSubmit={handleEmailPasswordSignIn} className="space-y-4">
                    <div className="space-y-2">
                      <Label htmlFor="signin-email" className="text-slate-300">
                        {t("email") || "Email"}
                      </Label>
                      <div className="relative">
                        <div className="absolute left-3 top-1/2 -translate-y-1/2 text-slate-400">
                          <Mail className="h-5 w-5" />
                        </div>
                        <Input
                          id="signin-email"
                          type="email"
                          placeholder="you@example.com"
                          value={email}
                          onChange={(e) => setEmail(e.target.value)}
                          required
                          disabled={isSubmitting}
                          className="pl-10 bg-slate-800 border-slate-700 text-white"
                        />
                      </div>
                    </div>

                    <div className="space-y-2">
                      <div className="flex justify-between">
                        <Label htmlFor="signin-password" className="text-slate-300">
                          {t("password") || "Password"}
                        </Label>
                        <Link
                          href="/forgot-password"
                          className="text-xs text-emerald-400 hover:text-emerald-300 transition-colors"
                        >
                          {t("forgotPassword") || "Forgot password?"}
                        </Link>
                      </div>
                      <div className="relative">
                        <div className="absolute left-3 top-1/2 -translate-y-1/2 text-slate-400">
                          <LockKeyhole className="h-5 w-5" />
                        </div>
                        <Input
                          id="signin-password"
                          type={showPassword ? "text" : "password"}
                          placeholder="••••••••"
                          value={password}
                          onChange={(e) => setPassword(e.target.value)}
                          required
                          disabled={isSubmitting}
                          className="pl-10 pr-10 bg-slate-800 border-slate-700 text-white"
                        />
                        <button
                          type="button"
                          onClick={() => setShowPassword(!showPassword)}
                          className="absolute right-3 top-1/2 -translate-y-1/2 text-slate-400 hover:text-slate-300"
                          tabIndex={-1}
                        >
                          {showPassword ? <EyeOff className="h-5 w-5" /> : <Eye className="h-5 w-5" />}
                        </button>
                      </div>
                    </div>

                    {authError && (
                      <Alert variant="destructive" className="bg-red-900/20 border-red-900 text-red-300">
                        <AlertCircle className="h-4 w-4" />
                        <AlertDescription>{authError}</AlertDescription>
                      </Alert>
                    )}

                    <Button
                      type="submit"
                      className="w-full bg-gradient-to-r from-emerald-600 to-teal-600 hover:from-emerald-700 hover:to-teal-700 text-white font-semibold py-5 rounded-lg transition-all duration-300"
                      disabled={isSubmitting}
                    >
                      {isSubmitting ? <Loader2 className="h-5 w-5 animate-spin mr-2" /> : null}
                      {t("signIn") || "Sign In"}
                      {!isSubmitting && <ArrowRight className="ml-2 h-5 w-5" />}
                    </Button>
                  </form>
                </TabsContent>

                {/* Sign Up Tab */}
                <TabsContent value="signup" className="space-y-4">
                  <form onSubmit={handleEmailPasswordSignUp} className="space-y-4">
                    <div className="space-y-2">
                      <Label htmlFor="signup-email" className="text-slate-300">
                        {t("email") || "Email"}
                      </Label>
                      <div className="relative">
                        <div className="absolute left-3 top-1/2 -translate-y-1/2 text-slate-400">
                          <Mail className="h-5 w-5" />
                        </div>
                        <Input
                          id="signup-email"
                          type="email"
                          placeholder="you@example.com"
                          value={email}
                          onChange={(e) => setEmail(e.target.value)}
                          required
                          disabled={isSubmitting}
                          className="pl-10 bg-slate-800 border-slate-700 text-white"
                        />
                      </div>
                    </div>

                    <div className="space-y-2">
                      <Label htmlFor="signup-password" className="text-slate-300">
                        {t("password") || "Password"}
                      </Label>
                      <div className="relative">
                        <div className="absolute left-3 top-1/2 -translate-y-1/2 text-slate-400">
                          <LockKeyhole className="h-5 w-5" />
                        </div>
                        <Input
                          id="signup-password"
                          type={showPassword ? "text" : "password"}
                          placeholder={t("createPassword") || "Create a password"}
                          value={password}
                          onChange={(e) => setPassword(e.target.value)}
                          required
                          minLength={6}
                          disabled={isSubmitting}
                          className="pl-10 pr-10 bg-slate-800 border-slate-700 text-white"
                        />
                        <button
                          type="button"
                          onClick={() => setShowPassword(!showPassword)}
                          className="absolute right-3 top-1/2 -translate-y-1/2 text-slate-400 hover:text-slate-300"
                          tabIndex={-1}
                        >
                          {showPassword ? <EyeOff className="h-5 w-5" /> : <Eye className="h-5 w-5" />}
                        </button>
                      </div>
                      <p className="text-xs text-slate-400">
                        {t("passwordRequirement") || "Password must be at least 6 characters long"}
                      </p>
                    </div>

                    {authError && (
                      <Alert variant="destructive" className="bg-red-900/20 border-red-900 text-red-300">
                        <AlertCircle className="h-4 w-4" />
                        <AlertDescription>{authError}</AlertDescription>
                      </Alert>
                    )}

                    <Button
                      type="submit"
                      className="w-full bg-gradient-to-r from-emerald-600 to-teal-600 hover:from-emerald-700 hover:to-teal-700 text-white font-semibold py-5 rounded-lg transition-all duration-300"
                      disabled={isSubmitting}
                    >
                      {isSubmitting ? <Loader2 className="h-5 w-5 animate-spin mr-2" /> : null}
                      {t("signUp") || "Sign Up"}
                      {!isSubmitting && <ArrowRight className="ml-2 h-5 w-5" />}
                    </Button>
                  </form>
                </TabsContent>
              </Tabs>

              {/* Divider */}
              <div className="relative my-6">
                <div className="absolute inset-0 flex items-center">
                  <Separator className="w-full border-slate-700" />
                </div>
                <div className="relative flex justify-center text-xs uppercase">
                  <span className="bg-slate-900 px-2 text-slate-400">{t("continueWith") || "Or continue with"}</span>
                </div>
              </div>

              {/* Google Sign-In Button */}
              <Button
                onClick={handleGoogleSignIn}
                variant="outline"
                className="w-full bg-slate-800 border-slate-700 text-white hover:bg-slate-700 hover:text-white transition-all duration-300"
                disabled={isSubmitting}
              >
                {isSubmitting ? (
                  <Loader2 className="mr-2 h-5 w-5 animate-spin" />
                ) : (
                  <svg
                    className="mr-2 h-5 w-5"
                    aria-hidden="true"
                    focusable="false"
                    data-prefix="fab"
                    data-icon="google"
                    role="img"
                    xmlns="http://www.w3.org/2000/svg"
                    viewBox="0 0 488 512"
                  >
                    <path
                      fill="currentColor"
                      d="M488 261.8C488 403.3 381.5 512 244.8 512 112.8 512 0 398.9 0 261.8 0 125.3 112.8 15.3 244.8 15.3c67.9 0 127.9 26.4 172.4 69.6L381.3 118C344.4 86.1 298.2 69.3 244.8 69.3c-94 0-170.4 76.6-170.4 170.4s76.4 170.4 170.4 170.4c60.1 0 108.1-24.1 139.9-66.4 24.8-32.5 32.5-77.3 32.5-111.2H244.8v-86h243.2z"
                    ></path>
                  </svg>
                )}
                {t("continueWithGoogle") || "Continue with Google"}
              </Button>
            </CardContent>
            <CardFooter className="flex flex-col items-center justify-center pt-2 pb-6 text-sm text-slate-400">
              <p>
                {activeTab === "signin"
                  ? t("dontHaveAccount") || "Don't have an account?"
                  : t("alreadyHaveAccount") || "Already have an account?"}{" "}
                <button
                  type="button"
                  onClick={() => setActiveTab(activeTab === "signin" ? "signup" : "signin")}
                  className="text-emerald-400 hover:text-emerald-300 font-medium transition-colors"
                >
                  {activeTab === "signin" ? t("signUp") || "Sign Up" : t("signIn") || "Sign In"}
                </button>
              </p>
              <p className="mt-4">
                {t("bySigningUp") || "By signing up, you agree to our"}{" "}
                <Link href="/terms" className="text-emerald-400 hover:text-emerald-300 transition-colors">
                  {t("terms") || "Terms"}
                </Link>{" "}
                {t("and") || "and"}{" "}
                <Link href="/privacy" className="text-emerald-400 hover:text-emerald-300 transition-colors">
                  {t("privacy") || "Privacy Policy"}
                </Link>
              </p>
            </CardFooter>
          </Card>
        </motion.div>
      </div>
    </div>
  )
}

// Main exported component wrapped in Suspense
export default function AuthPage() {
  const { t } = useLanguage()

  return (
    <Suspense fallback={
      <div className="flex justify-center items-center min-h-screen">
        <div className="flex flex-col items-center gap-4">
          <Loader2 className="h-12 w-12 animate-spin text-emerald-500" />
          <p className="text-muted-foreground animate-pulse">
            {t("loading") || "Loading..."}
          </p>
        </div>
      </div>
    }>
      <AuthContent />
    </Suspense>
  )
}
